from .horse_age import HorseAge as HorseAge
from _typeshed import Incomplete

class Horse:
    REGEX: Incomplete
    name: Incomplete
    country: Incomplete
    age: Incomplete
    def __init__(self, name, country: Incomplete | None = None, age_or_yob: Incomplete | None = None, *, context_date: Incomplete | None = None) -> None: ...
